import { ComponentFixture, TestBed } from '@angular/core/testing';
import { OgDhcpSubnetsComponent, Subnet } from './og-dhcp-subnets.component';
import { MatDialog } from '@angular/material/dialog';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';
import { of } from 'rxjs';
import { MatExpansionModule } from '@angular/material/expansion';
import { MatIconModule } from '@angular/material/icon';
import { MatDividerModule } from '@angular/material/divider';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatSelectModule } from '@angular/material/select';
import { MatPaginatorModule } from '@angular/material/paginator';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { FormsModule } from '@angular/forms';
import { MatInputModule } from '@angular/material/input';
import { MatTableModule } from '@angular/material/table';
import { TranslateModule } from '@ngx-translate/core';
import { JoyrideModule } from 'ngx-joyride';
import { LoadingComponent } from '../../shared/loading/loading.component';

describe('OgDhcpSubnetsComponent', () => {
  let component: OgDhcpSubnetsComponent;
  let fixture: ComponentFixture<OgDhcpSubnetsComponent>;
  let mockDialog: jasmine.SpyObj<MatDialog>;
  let mockHttpClient: jasmine.SpyObj<HttpClient>;
  let mockToastrService: jasmine.SpyObj<ToastrService>;

  beforeEach(async () => {
    mockDialog = jasmine.createSpyObj('MatDialog', ['open']);
    mockHttpClient = jasmine.createSpyObj('HttpClient', ['get', 'post', 'put', 'delete']);
    mockToastrService = jasmine.createSpyObj('ToastrService', ['success', 'error']);
    mockHttpClient.get.and.returnValue(of({ 'hydra:member': [], 'hydra:totalItems': 0 }));
    mockHttpClient.post.and.returnValue(of({}));

    await TestBed.configureTestingModule({
      declarations: [OgDhcpSubnetsComponent, LoadingComponent],
      imports: [
        MatExpansionModule,
        MatIconModule,
        MatDividerModule,
        MatFormFieldModule,
        MatSelectModule,
        MatPaginatorModule,
        BrowserAnimationsModule,
        FormsModule,
        MatInputModule,
        MatTableModule,
        TranslateModule.forRoot(),
        JoyrideModule.forRoot(),
      ],
      providers: [
        { provide: MatDialog, useValue: mockDialog },
        { provide: HttpClient, useValue: mockHttpClient },
        { provide: ToastrService, useValue: mockToastrService },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(OgDhcpSubnetsComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should call syncSubnets and handle success', () => {
    component.syncSubnets();
    expect(mockHttpClient.post).toHaveBeenCalledWith(`${component.baseUrl}/subnets/sync`, {});
    expect(mockToastrService.success).toHaveBeenCalledWith('Sincronización con componente DHCP exitosa');
  });

});
