import {Component, Inject, OnInit} from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {ToastrService} from "ngx-toastr";
import {Router} from "@angular/router";

@Component({
  selector: 'app-import-image',
  templateUrl: './import-image.component.html',
  styleUrl: './import-image.component.css'
})
export class ImportImageComponent implements OnInit{
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  loading: boolean = true;
  images: any[] = [];
  selectedClients: any[] = [];

  constructor(
    private http: HttpClient,
    public dialogRef: MatDialogRef<ImportImageComponent>,
    private toastService: ToastrService,
    private router: Router,
    @Inject(MAT_DIALOG_DATA) public data: { repository: any }
  ) {

  }

  ngOnInit(): void {
    this.loading = true;
    this.loadImages();
  }

  loadImages() {
    this.http.get<any>(`${this.baseUrl}/images?page=1&itemsPerPage=50`).subscribe(
      response => {
        this.images = response['hydra:member'];
        this.loading = false;
      },
      error => console.error('Error fetching organizational units:', error)
    );
  }

  getImageName(imageId: string): string {
    const image = this.images.find(img => img['@id'] === imageId);
    return image ? image.name : 'Desconocido';
  }

  removeImage(imageId: string) {
    this.selectedClients = this.selectedClients.filter(id => id !== imageId);
  }

  save() {
    this.http.post<any>(`${this.baseUrl}${this.data.repository['@id']}/import-image`, {
      images: this.selectedClients
    }).subscribe({
      next: (response) => {
        this.toastService.success('Peticion de importacion de imagen enviada correctamente');
        this.dialogRef.close();
        this.router.navigate(['/commands-logs']);
      },
      error: error => {
        this.toastService.error('Error al importar imagenes');
      }
    });
  }

  close() {
    this.dialogRef.close();
  }
}
